- Get Pendulum working with BucketTree, Ziptie, and FNC

- Get demo learning

- Create new Worlds
  - Cart pole
  - Double pendulum
  - Mountain car line

- Build new components
  - Incremental mean and variance estimate
